@@ -20,6 +20,13 @@ set -e
 
 case "$1" in
     configure)
+    if [ ! -f /etc/benno/rest.secret ];then
+        if [ -f /etc/benno-web/rest.conf ];then
+            cat /etc/benno-web/rest.conf | grep ^SHARED_SECRET |perl -pe 's/^.+=\s*//' >> /etc/benno/rest.secret
+        else
+            cat /dev/urandom | tr -dc 'a-zA-Z0-9' | fold -w 20 | head -n 1 > /etc/benno/rest.secret
+        fi
+    fi
     ;;
 
     abort-upgrade|abort-remove|abort-deconfigure)
